/**
 * Application configuration
 */
import { StringHelper } from '@bryntum/calendar/calendar.umd.js';

const calendarConfig = {
    // Start life looking at this date
    date : new Date(2021, 0, 1),

    // CrudManager arranges loading and syncing of data in JSON form from/to a web service
    crudManager : {
        transport : {
            load : {
                // The data set has multi assigned events
                url : 'data/data.json'
            },
            sync : {
                url : 'data/success.json',
                method : 'GET'
            }
        },
        autoLoad : true,
        autoSync : true
    },

    // Features named by the properties are included.
    // An object is used to configure the feature.
    eventTooltipFeature : {
        // Configuration options are passed on to the tooltip instance
        // We want the tooltip's left edge aligned to the right edge of the event if possible.
        align : 'l-r'
    },

    modes : {
        week : {
            // A custom event renderer outputting extra HTML
            eventRenderer({ eventRecord, renderData }) {
                let text = StringHelper.xss`<div class="event-name">${eventRecord.name}</div>`;

                const nbrAssigned = eventRecord.resources.length;

                if (nbrAssigned > 0) {
                    // Show an icon representing the amount of users assigned
                    text += `<small>${nbrAssigned} user${nbrAssigned > 1 ? 's' : ''} assigned</small>`;
                }

                return text;
            }
        }
    }
};

export { calendarConfig };
